@@ -13,6 +13,7 @@ from oead import (
 from oead.byml import Hash, Array
 from typing import List, Tuple
 from zlib import crc32
+import re
 
 from . import overrides
 
@@ -40,8 +41,6 @@ class BFUFlag:
             self.reset_type = flag["ResetType"].v
 
     def __eq__(self, other):
-        if not type(other) == BFUFlag:
-            return NotImplemented
         if self is other:
             return True
         if (
@@ -180,23 +179,23 @@ class BFUFlag:
         certain flag types are upheld.
         """
         OVERRIDES = overrides["STANDARD_OVERRIDES"]
-        for substr, value in OVERRIDES["OVERRIDE_IS_EVENT_ASSOCIATED"].items():
-            if substr in self._data_name:
+        for regex, value in OVERRIDES["OVERRIDE_IS_EVENT_ASSOCIATED"].items():
+            if re.search(regex, self.data_name):
                 self.is_event_associated = value
-        for substr, value in OVERRIDES["OVERRIDE_IS_ONE_TRIGGER"].items():
-            if substr in self._data_name:
+        for regex, value in OVERRIDES["OVERRIDE_IS_ONE_TRIGGER"].items():
+            if re.search(regex, self.data_name):
                 self.is_one_trigger = value
-        for substr, value in OVERRIDES["OVERRIDE_IS_PROGRAM_READABLE"].items():
-            if substr in self._data_name:
+        for regex, value in OVERRIDES["OVERRIDE_IS_PROGRAM_READABLE"].items():
+            if re.search(regex, self.data_name):
                 self.is_program_readable = value
-        for substr, value in OVERRIDES["OVERRIDE_IS_PROGRAM_WRITABLE"].items():
-            if substr in self._data_name:
+        for regex, value in OVERRIDES["OVERRIDE_IS_PROGRAM_WRITABLE"].items():
+            if re.search(regex, self.data_name):
                 self.is_program_writable = value
-        for substr, value in OVERRIDES["OVERRIDE_IS_SAVE"].items():
-            if substr in self._data_name:
+        for regex, value in OVERRIDES["OVERRIDE_IS_SAVE"].items():
+            if re.search(regex, self.data_name):
                 self.is_save = value
-        for substr, value in OVERRIDES["OVERRIDE_RESET_TYPE"].items():
-            if substr in self._data_name:
+        for regex, value in OVERRIDES["OVERRIDE_RESET_TYPE"].items():
+            if re.search(regex, self.data_name):
                 self.reset_type = value
 
 
@@ -207,7 +206,7 @@ class BoolFlag(BFUFlag):
         self.init_value = 0
         self.max_value = True
         self.min_value = False
-        self.revival = kwargs["revival"] if "revival" in kwargs else False
+        self.is_revival = kwargs["revival"] if "revival" in kwargs else False
         if flag:
             if not BoolFlag.validate_Hash(flag):
                 raise AttributeError(f"{flag['DataName']} is malformed.")
@@ -302,11 +301,11 @@ class BoolFlag(BFUFlag):
         """
         super(BoolFlag, self).use_name_to_override_params()
         OVERRIDES = overrides["BOOL_OVERRIDES"]
-        for substr, value in OVERRIDES["OVERRIDE_BOOL_CATEGORY"].items():
-            if substr in self._data_name:
+        for regex, value in OVERRIDES["OVERRIDE_BOOL_CATEGORY"].items():
+            if re.search(regex, self.data_name):
                 self.category = value
-        for substr, value in OVERRIDES["OVERRIDE_BOOL_INIT_VALUE"].items():
-            if substr in self._data_name:
+        for regex, value in OVERRIDES["OVERRIDE_BOOL_INIT_VALUE"].items():
+            if re.search(regex, self.data_name):
                 self.init_value = value
 
 
@@ -344,7 +343,7 @@ class BoolArrayFlag(BFUFlag):
             assert type(hash["InitValue"][0]) == Hash
             assert "Values" in hash["InitValue"][0]
             for value in hash["InitValue"][0]["Values"]:
-                assert value == S32
+                assert type(value) == S32
             assert type(hash["MaxValue"]) == bool
             assert type(hash["MinValue"]) == bool
             return True
@@ -396,24 +395,24 @@ class BoolArrayFlag(BFUFlag):
         """
         super(BoolArrayFlag, self).use_name_to_override_params()
         OVERRIDES = overrides["BOOL_ARRAY_OVERRIDES"]
-        for substr, value in OVERRIDES["OVERRIDE_BOOL_ARRAY_INIT_VALUE"].items():
-            if substr in self._data_name:
+        for regex, value in OVERRIDES["OVERRIDE_BOOL_ARRAY_INIT_VALUE"].items():
+            if re.search(regex, self.data_name):
                 self.init_value = value
-        for substr, value in OVERRIDES["OVERRIDE_BOOL_ARRAY_MAX_VALUE"].items():
-            if substr in self._data_name:
+        for regex, value in OVERRIDES["OVERRIDE_BOOL_ARRAY_MAX_VALUE"].items():
+            if re.search(regex, self.data_name):
                 self.max_value = value
-        for substr, value in OVERRIDES["OVERRIDE_BOOL_ARRAY_MIN_VALUE"].items():
-            if substr in self._data_name:
+        for regex, value in OVERRIDES["OVERRIDE_BOOL_ARRAY_MIN_VALUE"].items():
+            if re.search(regex, self.data_name):
                 self.min_value = value
 
 
 class S32Flag(BFUFlag):
     def __init__(self, flag: Hash = None, **kwargs) -> None:
         super(S32Flag, self).__init__(flag=flag)
-        self.revival = kwargs["revival"] if "revival" in kwargs else False
-        self._init_value = 0
-        self._max_value = 2147483647
-        self._min_value = 0
+        self.init_value = 0
+        self.max_value = 2147483647
+        self.min_value = 0
+        self.is_revival = kwargs["revival"] if "revival" in kwargs else False
         if flag:
             if not S32Flag.validate_Hash(flag):
                 raise AttributeError(f"{flag['DataName']} is malformed.")
@@ -427,9 +426,9 @@ class S32Flag(BFUFlag):
         if not super(S32Flag, self).__eq__(super(S32Flag, other)):
             return False
         if (
-            not self._init_value == other._init_value
-            or not self._max_value == other._max_value
-            or not self._min_value == other._min_value
+            not self.init_value == other.init_value
+            or not self.max_value == other.max_value
+            or not self.min_value == other.min_value
         ):
             return False
         return True
@@ -478,11 +477,11 @@ class S32Flag(BFUFlag):
 
     @property
     def is_revival(self) -> bool:
-        return self._is_revival
+        return self._revival
 
     @is_revival.setter
     def is_revival(self, revival: bool) -> None:
-        self._is_revival = revival
+        self._revival = revival
 
     def use_name_to_override_params(self) -> None:
         """
@@ -493,15 +492,15 @@ class S32Flag(BFUFlag):
         certain flag types are upheld.
         """
         super(S32Flag, self).use_name_to_override_params()
-        OVERRIDES = overrides["S32_OVERRRIDES"]
-        for substr, value in OVERRIDES["OVERRIDE_S32_INIT_VALUE"].items():
-            if substr in self._data_name:
+        OVERRIDES = overrides["S32_OVERRIDES"]
+        for regex, value in OVERRIDES["OVERRIDE_S32_INIT_VALUE"].items():
+            if re.search(regex, self.data_name):
                 self.init_value = value
-        for substr, value in OVERRIDES["OVERRIDE_S32_MAX_VALUE"].items():
-            if substr in self._data_name:
+        for regex, value in OVERRIDES["OVERRIDE_S32_MAX_VALUE"].items():
+            if re.search(regex, self.data_name):
                 self.max_value = value
-        for substr, value in OVERRIDES["OVERRIDE_S32_MIN_VALUE"].items():
-            if substr in self._data_name:
+        for regex, value in OVERRIDES["OVERRIDE_S32_MIN_VALUE"].items():
+            if re.search(regex, self.data_name):
                 self.min_value = value
 
 
@@ -539,7 +538,7 @@ class S32ArrayFlag(BFUFlag):
             assert type(hash["InitValue"][0]) == Hash
             assert "Values" in hash["InitValue"][0]
             for value in hash["InitValue"][0]["Values"]:
-                assert value == S32
+                assert type(value) == S32
             assert type(hash["MaxValue"]) == S32
             assert type(hash["MinValue"]) == S32
             return True
@@ -591,14 +590,14 @@ class S32ArrayFlag(BFUFlag):
         """
         super(S32ArrayFlag, self).use_name_to_override_params()
         OVERRIDES = overrides["S32_ARRAY_OVERRIDES"]
-        for substr, value in OVERRIDES["OVERRIDE_S32_ARRAY_INIT_VALUE"].items():
-            if substr in self._data_name:
+        for regex, value in OVERRIDES["OVERRIDE_S32_ARRAY_INIT_VALUE"].items():
+            if re.search(regex, self.data_name):
                 self.init_value = value
-        for substr, value in OVERRIDES["OVERRIDE_S32_ARRAY_MAX_VALUE"].items():
-            if substr in self._data_name:
+        for regex, value in OVERRIDES["OVERRIDE_S32_ARRAY_MAX_VALUE"].items():
+            if re.search(regex, self.data_name):
                 self.max_value = value
-        for substr, value in OVERRIDES["OVERRIDE_S32_ARRAY_MIN_VALUE"].items():
-            if substr in self._data_name:
+        for regex, value in OVERRIDES["OVERRIDE_S32_ARRAY_MIN_VALUE"].items():
+            if re.search(regex, self.data_name):
                 self.min_value = value
 
 
@@ -680,14 +679,14 @@ class F32Flag(BFUFlag):
         """
         super(F32Flag, self).use_name_to_override_params()
         OVERRIDES = overrides["F32_OVERRIDES"]
-        for substr, value in OVERRIDES["OVERRIDE_F32_INIT_VALUE"].items():
-            if substr in self._data_name:
+        for regex, value in OVERRIDES["OVERRIDE_F32_INIT_VALUE"].items():
+            if re.search(regex, self.data_name):
                 self.init_value = value
-        for substr, value in OVERRIDES["OVERRIDE_F32_MAX_VALUE"].items():
-            if substr in self._data_name:
+        for regex, value in OVERRIDES["OVERRIDE_F32_MAX_VALUE"].items():
+            if re.search(regex, self.data_name):
                 self.max_value = value
-        for substr, value in OVERRIDES["OVERRIDE_F32_MIN_VALUE"].items():
-            if substr in self._data_name:
+        for regex, value in OVERRIDES["OVERRIDE_F32_MIN_VALUE"].items():
+            if re.search(regex, self.data_name):
                 self.min_value = value
 
 
@@ -725,7 +724,7 @@ class F32ArrayFlag(BFUFlag):
             assert type(hash["InitValue"][0]) == Hash
             assert "Values" in hash["InitValue"][0]
             for value in hash["InitValue"][0]["Values"]:
-                assert value == F32
+                assert type(value) == F32
             assert type(hash["MaxValue"]) == F32
             assert type(hash["MinValue"]) == F32
             return True
@@ -777,14 +776,14 @@ class F32ArrayFlag(BFUFlag):
         """
         super(F32ArrayFlag, self).use_name_to_override_params()
         OVERRIDES = overrides["F32_ARRAY_OVERRIDES"]
-        for substr, value in OVERRIDES["OVERRIDE_F32_ARRAY_INIT_VALUE"].items():
-            if substr in self._data_name:
+        for regex, value in OVERRIDES["OVERRIDE_F32_ARRAY_INIT_VALUE"].items():
+            if re.search(regex, self.data_name):
                 self.init_value = value
-        for substr, value in OVERRIDES["OVERRIDE_F32_ARRAY_MAX_VALUE"].items():
-            if substr in self._data_name:
+        for regex, value in OVERRIDES["OVERRIDE_F32_ARRAY_MAX_VALUE"].items():
+            if re.search(regex, self.data_name):
                 self.max_value = value
-        for substr, value in OVERRIDES["OVERRIDE_F32_ARRAY_MIN_VALUE"].items():
-            if substr in self._data_name:
+        for regex, value in OVERRIDES["OVERRIDE_F32_ARRAY_MIN_VALUE"].items():
+            if re.search(regex, self.data_name):
                 self.min_value = value
 
 
@@ -802,7 +801,7 @@ class StringFlag(BFUFlag):
             self.min_value = flag["MinValue"]
 
     def __eq__(self, other):
-        if not type(other) == StringFlag:
+        if not isinstance(other, StringFlag):
             return NotImplemented
         if not super(StringFlag, self).__eq__(super(StringFlag, other)):
             return False
@@ -863,14 +862,14 @@ class StringFlag(BFUFlag):
         """
         super(StringFlag, self).use_name_to_override_params()
         OVERRIDES = overrides["STRING_OVERRIDES"]
-        for substr, value in OVERRIDES["OVERRIDE_STRING_INIT_VALUE"].items():
-            if substr in self._data_name:
+        for regex, value in OVERRIDES["OVERRIDE_STRING_INIT_VALUE"].items():
+            if re.search(regex, self.data_name):
                 self.init_value = value
-        for substr, value in OVERRIDES["OVERRIDE_STRING_MAX_VALUE"].items():
-            if substr in self._data_name:
+        for regex, value in OVERRIDES["OVERRIDE_STRING_MAX_VALUE"].items():
+            if re.search(regex, self.data_name):
                 self.max_value = value
-        for substr, value in OVERRIDES["OVERRIDE_STRING_MIN_VALUE"].items():
-            if substr in self._data_name:
+        for regex, value in OVERRIDES["OVERRIDE_STRING_MIN_VALUE"].items():
+            if re.search(regex, self.data_name):
                 self.min_value = value
 
 
@@ -933,7 +932,7 @@ class StringArrayFlag(BFUFlag):
             self.min_value = flag["MinValue"]
 
     def __eq__(self, other):
-        if not type(other) == StringArrayFlag:
+        if not isinstance(other, StringArrayFlag):
             return NotImplemented
         if not super(StringArrayFlag, self).__eq__(super(StringArrayFlag, other)):
             return False
@@ -953,7 +952,7 @@ class StringArrayFlag(BFUFlag):
             assert type(hash["InitValue"][0]) == Hash
             assert "Values" in hash["InitValue"][0]
             for value in hash["InitValue"][0]["Values"]:
-                assert value == str
+                assert type(value) == str
             assert type(hash["MaxValue"]) == str
             assert type(hash["MinValue"]) == str
             return True
@@ -998,14 +997,14 @@ class StringArrayFlag(BFUFlag):
         """
         super(StringArrayFlag, self).use_name_to_override_params()
         OVERRIDES = overrides["STRING_ARRAY_OVERRIDES"]
-        for substr, value in OVERRIDES["OVERRIDE_STRING_ARRAY_INIT_VALUE"].items():
-            if substr in self._data_name:
+        for regex, value in OVERRIDES["OVERRIDE_STRING_ARRAY_INIT_VALUE"].items():
+            if re.search(regex, self.data_name):
                 self.init_value = value
-        for substr, value in OVERRIDES["OVERRIDE_STRING_ARRAY_MAX_VALUE"].items():
-            if substr in self._data_name:
+        for regex, value in OVERRIDES["OVERRIDE_STRING_ARRAY_MAX_VALUE"].items():
+            if re.search(regex, self.data_name):
                 self.max_value = value
-        for substr, value in OVERRIDES["OVERRIDE_STRING_ARRAY_MIN_VALUE"].items():
-            if substr in self._data_name:
+        for regex, value in OVERRIDES["OVERRIDE_STRING_ARRAY_MIN_VALUE"].items():
+            if re.search(regex, self.data_name):
                 self.min_value = value
 
 
@@ -1143,14 +1142,14 @@ class Vec2Flag(BFUFlag):
         """
         super(Vec2Flag, self).use_name_to_override_params()
         OVERRIDES = overrides["VEC2_OVERRIDES"]
-        for substr, value in OVERRIDES["OVERRIDE_VEC2_INIT_VALUE"].items():
-            if substr in self._data_name:
+        for regex, value in OVERRIDES["OVERRIDE_VEC2_INIT_VALUE"].items():
+            if re.search(regex, self.data_name):
                 self.init_value = value
-        for substr, value in OVERRIDES["OVERRIDE_VEC2_MAX_VALUE"].items():
-            if substr in self._data_name:
+        for regex, value in OVERRIDES["OVERRIDE_VEC2_MAX_VALUE"].items():
+            if re.search(regex, self.data_name):
                 self.max_value = value
-        for substr, value in OVERRIDES["OVERRIDE_VEC2_MIN_VALUE"].items():
-            if substr in self._data_name:
+        for regex, value in OVERRIDES["OVERRIDE_VEC2_MIN_VALUE"].items():
+            if re.search(regex, self.data_name):
                 self.min_value = value
 
 
@@ -1191,8 +1190,8 @@ class Vec2ArrayFlag(BFUFlag):
             assert type(hash["InitValue"][0]) == Hash
             assert "Values" in hash["InitValue"][0]
             for value in hash["InitValue"][0]["Values"]:
-                assert value[0][0] == F32
-                assert value[0][1] == F32
+                assert type(value[0][0]) == F32
+                assert type(value[0][1]) == F32
             assert type(hash["MaxValue"][0][0]) == F32
             assert type(hash["MaxValue"][0][1]) == F32
             assert type(hash["MinValue"][0][0]) == F32
@@ -1262,14 +1261,14 @@ class Vec2ArrayFlag(BFUFlag):
         """
         super(Vec2ArrayFlag, self).use_name_to_override_params()
         OVERRIDES = overrides["VEC2_ARRAY_OVERRIDES"]
-        for substr, value in OVERRIDES["OVERRIDE_VEC2_ARRAY_INIT_VALUE"].items():
-            if substr in self._data_name:
+        for regex, value in OVERRIDES["OVERRIDE_VEC2_ARRAY_INIT_VALUE"].items():
+            if re.search(regex, self.data_name):
                 self.init_value = value
-        for substr, value in OVERRIDES["OVERRIDE_VEC2_ARRAY_MAX_VALUE"].items():
-            if substr in self._data_name:
+        for regex, value in OVERRIDES["OVERRIDE_VEC2_ARRAY_MAX_VALUE"].items():
+            if re.search(regex, self.data_name):
                 self.max_value = value
-        for substr, value in OVERRIDES["OVERRIDE_VEC2_ARRAY_MIN_VALUE"].items():
-            if substr in self._data_name:
+        for regex, value in OVERRIDES["OVERRIDE_VEC2_ARRAY_MIN_VALUE"].items():
+            if re.search(regex, self.data_name):
                 self.min_value = value
 
 
@@ -1387,14 +1386,14 @@ class Vec3Flag(BFUFlag):
         """
         super(Vec3Flag, self).use_name_to_override_params()
         OVERRIDES = overrides["VEC3_OVERRIDES"]
-        for substr, value in OVERRIDES["OVERRIDE_VEC3_INIT_VALUE"].items():
-            if substr in self._data_name:
+        for regex, value in OVERRIDES["OVERRIDE_VEC3_INIT_VALUE"].items():
+            if re.search(regex, self.data_name):
                 self.init_value = value
-        for substr, value in OVERRIDES["OVERRIDE_VEC3_MAX_VALUE"].items():
-            if substr in self._data_name:
+        for regex, value in OVERRIDES["OVERRIDE_VEC3_MAX_VALUE"].items():
+            if re.search(regex, self.data_name):
                 self.max_value = value
-        for substr, value in OVERRIDES["OVERRIDE_VEC3_MIN_VALUE"].items():
-            if substr in self._data_name:
+        for regex, value in OVERRIDES["OVERRIDE_VEC3_MIN_VALUE"].items():
+            if re.search(regex, self.data_name):
                 self.min_value = value
 
 
@@ -1443,9 +1442,9 @@ class Vec3ArrayFlag(BFUFlag):
             assert type(hash["InitValue"][0]) == Hash
             assert "Values" in hash["InitValue"][0]
             for value in hash["InitValue"][0]["Values"]:
-                assert value[0][0] == F32
-                assert value[0][1] == F32
-                assert value[0][2] == F32
+                assert type(value[0][0]) == F32
+                assert type(value[0][1]) == F32
+                assert type(value[0][2]) == F32
             assert type(hash["MaxValue"][0][0]) == F32
             assert type(hash["MaxValue"][0][1]) == F32
             assert type(hash["MaxValue"][0][2]) == F32
@@ -1520,14 +1519,14 @@ class Vec3ArrayFlag(BFUFlag):
         """
         super(Vec3ArrayFlag, self).use_name_to_override_params()
         OVERRIDES = overrides["VEC3_ARRAY_OVERRIDES"]
-        for substr, value in OVERRIDES["OVERRIDE_VEC3_ARRAY_INIT_VALUE"].items():
-            if substr in self._data_name:
+        for regex, value in OVERRIDES["OVERRIDE_VEC3_ARRAY_INIT_VALUE"].items():
+            if re.search(regex, self.data_name):
                 self.init_value = value
-        for substr, value in OVERRIDES["OVERRIDE_VEC3_ARRAY_MAX_VALUE"].items():
-            if substr in self._data_name:
+        for regex, value in OVERRIDES["OVERRIDE_VEC3_ARRAY_MAX_VALUE"].items():
+            if re.search(regex, self.data_name):
                 self.max_value = value
-        for substr, value in OVERRIDES["OVERRIDE_VEC3_ARRAY_MIN_VALUE"].items():
-            if substr in self._data_name:
+        for regex, value in OVERRIDES["OVERRIDE_VEC3_ARRAY_MIN_VALUE"].items():
+            if re.search(regex, self.data_name):
                 self.min_value = value
 
 
@@ -1654,12 +1653,12 @@ class Vec4Flag(BFUFlag):
         """
         super(Vec4Flag, self).use_name_to_override_params()
         OVERRIDES = overrides["VEC4_OVERRIDES"]
-        for substr, value in OVERRIDES["OVERRIDE_VEC4_INIT_VALUE"].items():
-            if substr in self._data_name:
+        for regex, value in OVERRIDES["OVERRIDE_VEC4_INIT_VALUE"].items():
+            if re.search(regex, self.data_name):
                 self.init_value = value
-        for substr, value in OVERRIDES["OVERRIDE_VEC4_MAX_VALUE"].items():
-            if substr in self._data_name:
+        for regex, value in OVERRIDES["OVERRIDE_VEC4_MAX_VALUE"].items():
+            if re.search(regex, self.data_name):
                 self.max_value = value
-        for substr, value in OVERRIDES["OVERRIDE_VEC4_MIN_VALUE"].items():
-            if substr in self._data_name:
+        for regex, value in OVERRIDES["OVERRIDE_VEC4_MIN_VALUE"].items():
+            if re.search(regex, self.data_name):
                 self.min_value = value
